"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.withAuth = withAuth;

var _server = require("next/server");

var _jwt = require("../jwt");

async function withAuth(...args) {
  var _options$secret;

  if (args.length === 2) {
    const secret = process.env.NEXTAUTH_SECRET;

    if (!secret) {
      const code = "NO_SECRET";
      console.error(`[next-auth][error][${code}]`, `\nhttps://next-auth.js.org/errors#${code.toLowerCase()}`);
      return _server.NextResponse.redirect("/api/auth/error?error=Configuration");
    }

    const req = args[0];
    if (await (0, _jwt.getToken)({
      req: req,
      secret
    })) return;
    return _server.NextResponse.redirect(`/api/auth/signin?${new URLSearchParams({
      callbackUrl: req.url
    })}`);
  }

  const options = args[0];
  const secret = (_options$secret = options === null || options === void 0 ? void 0 : options.secret) !== null && _options$secret !== void 0 ? _options$secret : process.env.NEXTAUTH_SECRET;
  return async function middleware(req) {
    var _options$pages, _options$authorized, _pages$signIn;

    const pages = (_options$pages = options === null || options === void 0 ? void 0 : options.pages) !== null && _options$pages !== void 0 ? _options$pages : {};
    const {
      pathname
    } = req.nextUrl;

    if (pathname === pages.signIn || pathname === pages.error) {
      return;
    }

    if (!secret) {
      var _options$pages$error, _options$pages2;

      const code = "NO_SECRET";
      console.error(`[next-auth][error][${code}]`, `\nhttps://next-auth.js.org/errors#${code.toLowerCase()}`);
      return _server.NextResponse.redirect((_options$pages$error = options === null || options === void 0 ? void 0 : (_options$pages2 = options.pages) === null || _options$pages2 === void 0 ? void 0 : _options$pages2.error) !== null && _options$pages$error !== void 0 ? _options$pages$error : "/api/auth/error?error=Configuration");
    }

    const token = await (0, _jwt.getToken)({
      req: req,
      secret
    });
    const isAuthorized = options !== null && options !== void 0 && options.authorized ? options === null || options === void 0 ? void 0 : (_options$authorized = options.authorized) === null || _options$authorized === void 0 ? void 0 : _options$authorized.call(options, {
      token,
      req
    }) : !!token;
    if (isAuthorized) return;
    const redirectUrl = (_pages$signIn = pages.signIn) !== null && _pages$signIn !== void 0 ? _pages$signIn : "/api/auth/signin";
    return _server.NextResponse.redirect(`${redirectUrl}?${new URLSearchParams({
      callbackUrl: req.url
    })}`);
  };
}

var _default = withAuth;
exports.default = _default;